




[AI Compiler]
https://www.usenix.org/system/files/osdi24-wang-lei.pdf




[]
- https://github.com/rasbt/LLMs-from-scratch
- https://www.gilesthomas.com/2025/03/llm-from-scratch-8-trainable-self-attention
https://www.gilesthomas.com/2024/12/llm-from-scratch-2